@@ -3,14 +3,13 @@ import copy
 import json
 import os
 import re
-from typing import Any, Callable, Literal, TypeVar, Union, cast
+from typing import Any, Callable, Literal, TypeVar, Union, cast, Optional
 from urllib.parse import urljoin
 
 import requests
 from gable.openapi import (
     CheckComplianceDataAssetsPySparkRequest,
     CheckComplianceDataAssetsS3Request,
-    CheckComplianceDataAssetsTypeScriptRequest,
     CheckDataAssetCommentMarkdownResponse,
     CheckDataAssetDetailedResponse,
     CheckDataAssetErrorResponse,
@@ -27,6 +26,7 @@ from gable.openapi import (
     ErrorResponse,
     ErrorResponseDeprecated,
     GetNpmCredentialsResponse,
+    GetPipCredentialsResponse,
     IngestDataAssetResponse,
     PostContractRequest,
     PostContractResponse,
@@ -34,11 +34,12 @@ from gable.openapi import (
     RegisterDataAssetS3Request,
     RegisterDataAssetsRequest,
     RegisterDataAssetsResponse,
-    RegisterDataAssetTypeScriptRequest,
     ResponseType,
+    PostScaStartRunRequest,
+    PostScaStartRunResponse
 )
 from loguru import logger
-from pydantic import Field, parse_obj_as
+from pydantic import parse_obj_as
 
 T = TypeVar("T")
 
@@ -183,12 +184,26 @@ class GableAPIClient:
             )
         return response
 
-    def post_data_assets_check(self, request) -> Union[list[Any], dict[str, Any]]:
-        result, _success, _status_code = self._post(
-            "v0/data-assets/check",
-            json=del_none(request),
-        )
-        return result
+    def get_auth_pip(self) -> GetPipCredentialsResponse:
+        """
+        Get the PIP credentials for the current user
+        """
+        try:
+            response, success, status_code = self._get(
+                "v0/auth/pip",
+                log_response_filter=GET_NPM_AUTH_TOKEN_RESPONSE_FILTER_LAMBDA,
+            )
+            response = GetPipCredentialsResponse.parse_obj(response)
+        except Exception as e:
+            logger.opt(exception=e).debug("Error getting PIP credentials")
+            raise Exception(
+                f"Error getting PIP credentials: {e}. Re-run with --debug for more information."
+            )
+        if not success:
+            raise Exception(
+                f"Failed to get PIP credentials: ({status_code}) {response}"
+            )
+        return response
 
     def post_data_assets_check_compliance(
         self, request: DataAssetsCheckComplianceRequest
@@ -221,35 +236,6 @@ class GableAPIClient:
         else:
             return ErrorResponse.parse_obj(result)
 
-    def post_data_asset_ingest(self, request):
-        result, success, status_code = self._post(
-            "v0/data-asset/ingest",
-            json=del_none(request),
-        )
-        return cast(dict[str, Any], result), success, status_code
-
-    def post_data_asset_register_typescript(
-        self, request: RegisterDataAssetTypeScriptRequest
-    ):
-        json_payload = request.dict(by_alias=True)
-
-        # Convert the OpenAPI Enum string
-        for asset in json_payload["assets"]:
-            asset["library"] = asset["library"].value
-
-        result, success, status_code = self._post(
-            "v0/data-asset/register/typescript", json=json_payload
-        )
-        if isinstance(result, dict) and "registered" in result:
-            response = IngestDataAssetResponse.parse_obj(result)
-        else:
-            response = ErrorResponseDeprecated.parse_obj(result)
-        return (
-            response,
-            success,
-            status_code,
-        )
-
     def post_data_asset_register_pyspark(
         self, request: RegisterDataAssetPySparkRequest
     ) -> tuple[Union[IngestDataAssetResponse, ErrorResponseDeprecated], bool, int]:
@@ -314,21 +300,6 @@ class GableAPIClient:
             request.responseType, response
         )
 
-    def post_check_compliance_data_assets_typescript(
-        self, request: CheckComplianceDataAssetsTypeScriptRequest
-    ) -> Union[
-        ErrorResponse,
-        CheckDataAssetCommentMarkdownResponse,
-        list[CheckDataAssetResponse],
-    ]:
-        response, _success, _status_code = self._post(
-            "v0/data-assets/check-compliance/typescript",
-            data=request.json(by_alias=True, exclude_none=True),
-        )
-        return parse_data_assets_check_compliance_response(
-            request.responseType, response
-        )
-
     def post_telemetry(
         self, request: CreateTelemetryRequest
     ) -> tuple[Union[CreateTelemetryResponse, ErrorResponse], bool]:
@@ -340,6 +311,17 @@ class GableAPIClient:
         else:
             return ErrorResponse.parse_obj(response), success
 
+    def post_sca_start_run(
+        self,
+        request: PostScaStartRunRequest,
+    ) -> tuple[Union[PostScaStartRunResponse, ErrorResponse], bool, int]:
+        """Start a new SCA run with the given parameters."""
+        response, success, status_code = self._post("v0/sca/start-run", json=json.loads(request.json(by_alias=True, exclude_none=True)))
+        if success:
+            return PostScaStartRunResponse.parse_obj(response), success, status_code
+        else:
+            return ErrorResponse.parse_obj(response), success, status_code
+
     def get_data_asset(
         self, data_asset_resource_name: str
     ) -> Union[DataAsset, ErrorResponse]:
@@ -378,8 +360,44 @@ class GableAPIClient:
     def get_ping(self):
         return self._get("v0/ping")
 
-    def get_contracts(self) -> list[ContractOutput]:
-        response, success, status_code = self._get("v0/contracts")
+    def get_contract(self, contract_id) -> ContractOutput:
+        response, success, status_code = self._get("v0/contract/" + contract_id)
+        if not success or not isinstance(response, ContractOutput):
+            error_message = (
+                response.get("message", "Unknown error")
+                if isinstance(response, dict)
+                else "Unexpected response format"
+            )
+            raise Exception(
+                f"Failed to retrieve contract {contract_id}: {error_message}, status code: {status_code}"
+            )
+        return ContractOutput.parse_obj(response)
+
+    def get_contracts(
+        self,
+        search: Optional[str] = None,
+        limit: Optional[int] = None,
+        offset: Optional[int] = None,
+        order_by: Optional[str] = None,
+        order_dir: Optional[str] = None,
+        status: Optional[str] = None,
+    ) -> list[ContractOutput]:
+        # Build query parameters
+        params = {}
+        if search is not None:
+            params["search"] = search
+        if limit is not None:
+            params["limit"] = limit
+        if offset is not None:
+            params["offset"] = offset
+        if order_by is not None:
+            params["orderBy"] = order_by
+        if order_dir is not None:
+            params["orderDir"] = order_dir
+        if status is not None:
+            params["status"] = status
+
+        response, success, status_code = self._get("v0/contracts", params=params)
         if not success or not isinstance(response, list):
             error_message = (
                 response.get("message", "Unknown error")
