@@ -15,10 +15,10 @@ from gable.cli.commands.asset_plugins.baseclass import (
 from gable.cli.helpers.data_asset import get_git_repo, get_relative_project_path
 from gable.cli.helpers.emoji import EMOJI
 from gable.cli.helpers.npm import (
-    get_sca_prime_shadow_results,
+    get_sca_prime_results,
     prepare_npm_environment,
     run_sca_npx_help,
-    start_sca_prime_shadow,
+    start_sca_prime,
 )
 from gable.openapi import SourceType, StructuredDataAssetResourceName
 from loguru import logger
@@ -86,7 +86,7 @@ class SwiftAssetPlugin(AssetPluginAbstract):
             run_sca_npx_help(client.endpoint)
             semgrep_bin_path = self.install_semgrep()
 
-            sca_prime_future = start_sca_prime_shadow(
+            sca_prime_future = start_sca_prime(
                 client=client,
                 project_root=project_root,
                 annotations=annotations,
@@ -94,7 +94,7 @@ class SwiftAssetPlugin(AssetPluginAbstract):
                 semgrep_bin_path=semgrep_bin_path,
             )
 
-            results, locations = get_sca_prime_shadow_results(
+            results, locations = get_sca_prime_results(
                 sca_prime_future,
                 client,
                 project_root,
@@ -149,7 +149,18 @@ class SwiftAssetPlugin(AssetPluginAbstract):
 
             log_message = "Detected asset: \n" + asset_type + " " + asset_name + " {\n"
             for field in asset_fields:
-                log_message += f"  {field['name']}: {field['type']}\n"
+                log_message += f"  {field['name']}: {field['type']}"
+                if field["type"] == "union":
+                    log_message += (
+                        "[" + ", ".join([x["type"] for x in field["types"]]) + "]"
+                    )
+                elif field["type"] == "list":
+                    log_message += f"[{field['values']['type']}]"
+                elif field["type"] == "map":
+                    log_message += (
+                        f"[{field['keys']['type']}: {field['values']['type']}]"
+                    )
+                log_message += "\n"
             log_message += "}\n"
             location = (
                 source_location["file_path"]
@@ -157,7 +168,7 @@ class SwiftAssetPlugin(AssetPluginAbstract):
                 + str(source_location["start"]["line"])
             )
             log_message += f"Location: {location}\n"
-            logger.info(log_message)
+            logger.debug(log_message)
 
         except KeyError as e:
             logger.warning(
