@@ -2,22 +2,19 @@ from typing import Optional, Union, cast
 
 import click
 from click.core import Context as ClickContext
-from gable.cli.helpers.check import post_data_assets_check_requests
+from gable.cli.commands.asset_plugins.avro import AvroAssetPlugin
+from gable.cli.commands.asset_plugins.mssql import MsSQLAssetPlugin
+from gable.cli.commands.asset_plugins.mysql import MySQLAssetPlugin
+from gable.cli.commands.asset_plugins.postgres import PostgresAssetPlugin
+from gable.cli.commands.asset_plugins.protobuf import ProtobufAssetPlugin
+from gable.cli.commands.asset_plugins.pyspark import PysparkAssetPlugin
+from gable.cli.commands.asset_plugins.python import PythonAssetPlugin
+from gable.cli.commands.asset_plugins.typescript import TypescriptAssetPlugin
+from gable.cli.commands.data_asset_check_plugin import plugin_check
 from gable.cli.helpers.data_asset import (
     determine_should_block,
     format_check_data_assets_json_output,
     format_check_data_assets_text_output,
-    gather_python_asset_data,
-    get_schema_contents,
-    get_source_names,
-    is_empty_schema_contents,
-)
-from gable.cli.helpers.data_asset_pyspark import (
-    check_compliance_pyspark_data_asset,
-    read_config_file,
-)
-from gable.cli.helpers.data_asset_typescript import (
-    check_compliance_typescript_data_asset,
 )
 from gable.cli.helpers.emoji import EMOJI
 from gable.cli.options import (
@@ -29,7 +26,7 @@ from gable.cli.options import (
     s3_project_options,
     typescript_project_options,
 )
-from gable.common_types import ALL_SOURCE_TYPES, FILE_SOURCE_TYPES, SCHEMA_SOURCE_TYPES
+from gable.common_types import ALL_SOURCE_TYPES
 from gable.openapi import (
     CheckDataAssetCommentMarkdownResponse,
     CheckDataAssetResponse,
@@ -153,6 +150,7 @@ def check_data_asset(
     emitter_name_parameter: str,
     event_name_key: str,
     emitter_file_path: str,
+    emitter_location: Optional[str],
     library: Optional[str],
     node_modules_include: Optional[str],
     spark_job_entrypoint: Optional[str],
@@ -185,126 +183,164 @@ def check_data_asset(
     schema_contents = []
     source_names = []
     if source_type == SourceType.python:
-        # Click options should enforce these being required, but to make pyright happy check anyways
-        if (
-            not project_root
-            or not emitter_function
-            or not emitter_payload_parameter
-            or not emitter_file_path
-            or not event_name_key
-        ):
-            raise click.ClickException(
-                f"{EMOJI.RED_X.value} Missing required options for Python project registration. You can use the --debug or --trace flags for more details."
-            )
-        source_names, schema_contents = gather_python_asset_data(
-            project_root,
-            emitter_file_path,
-            emitter_function,
-            emitter_payload_parameter,
-            event_name_key,
-            exclude,
-            ctx.obj.client,
-        )
-        if is_empty_schema_contents(source_type, schema_contents):
-            raise click.ClickException(
-                f"{EMOJI.RED_X.value} No data assets found to check! You can use the --debug or --trace flags for more details."
-            )
-        results = post_data_assets_check_requests(
-            ctx.obj.client,
-            response_type,
-            source_type,
+        # use the python asset plugin
+        python_asset_plugin = PythonAssetPlugin()
+        kwargs = {
+            "project_root": project_root,
+            "emitter_file_path": emitter_file_path,
+            "emitter_function": emitter_function,
+            "emitter_payload_parameter": emitter_payload_parameter,
+            "event_name_key": event_name_key,
+            "exclude": exclude,
+        }
+        plugin_check(
+            python_asset_plugin,
+            output,  # type: ignore
             include_unchanged_assets,
-            source_names,
-            db,
-            schema,
-            schema_contents,
+            kwargs,
+            ctx,
         )
-    elif source_type in SCHEMA_SOURCE_TYPES or source_type in FILE_SOURCE_TYPES:
-        schema_contents = get_schema_contents(
-            source_type=source_type,
-            dbuser=proxy_user,
-            dbpassword=proxy_password,
-            db=proxy_db or db,
-            dbhost=proxy_host,
-            dbport=proxy_port,
-            schema=proxy_schema or schema,
-            tables=tables,
-            files=[] if files is None else list(files),
-        )
-        source_names = get_source_names(
-            ctx=ctx,
-            source_type=source_type,
-            dbhost=host,
-            dbport=port,
-            files=[] if files is None else list(files),
-        )
-        if is_empty_schema_contents(source_type, schema_contents):
-            raise click.ClickException(
-                f"{EMOJI.RED_X.value} No data assets found to check! You can use the --debug or --trace flags for more details."
-            )
-        results = post_data_assets_check_requests(
-            ctx.obj.client,
-            response_type,
-            source_type,
+        return
+    elif source_type == SourceType.mysql:
+        asset_plugin = MySQLAssetPlugin()
+        kwargs = {
+            "host": host,
+            "port": port,
+            "db": db,
+            "schema": schema,
+            "table": table,
+            "proxy_host": proxy_host,
+            "proxy_port": proxy_port,
+            "proxy_db": proxy_db,
+            "proxy_schema": proxy_schema,
+            "proxy_user": proxy_user,
+            "proxy_password": proxy_password,
+            "include_unchanged_assets": include_unchanged_assets,
+        }
+        plugin_check(
+            asset_plugin,
+            output,  # type: ignore
             include_unchanged_assets,
-            source_names,
-            db,
-            schema,
-            schema_contents,
+            kwargs,
+            ctx,
         )
+        return
+    elif source_type == SourceType.postgres:
+        asset_plugin = PostgresAssetPlugin()
+        kwargs = {
+            "host": host,
+            "port": port,
+            "db": db,
+            "schema": schema,
+            "table": table,
+            "proxy_host": proxy_host,
+            "proxy_port": proxy_port,
+            "proxy_db": proxy_db,
+            "proxy_schema": proxy_schema,
+            "proxy_user": proxy_user,
+            "proxy_password": proxy_password,
+            "include_unchanged_assets": include_unchanged_assets,
+        }
+        plugin_check(
+            asset_plugin,
+            output,  # type: ignore
+            include_unchanged_assets,
+            kwargs,
+            ctx,
+        )
+        return
+    elif source_type == SourceType.mssql:
+        asset_plugin = MsSQLAssetPlugin()
+        kwargs = {
+            "host": host,
+            "port": port,
+            "db": db,
+            "schema": schema,
+            "table": table,
+            "proxy_host": proxy_host,
+            "proxy_port": proxy_port,
+            "proxy_db": proxy_db,
+            "proxy_schema": proxy_schema,
+            "proxy_user": proxy_user,
+            "proxy_password": proxy_password,
+            "include_unchanged_assets": include_unchanged_assets,
+        }
+        plugin_check(
+            asset_plugin,
+            output,  # type: ignore
+            include_unchanged_assets,
+            kwargs,
+            ctx,
+        )
+        return
+    elif source_type == SourceType.avro:
+        asset_plugin = AvroAssetPlugin()
+        kwargs = {
+            "files": files,
+            "include_unchanged_assets": include_unchanged_assets,
+        }
+        plugin_check(
+            asset_plugin,
+            output,  # type: ignore
+            include_unchanged_assets,
+            kwargs,
+            ctx,
+        )
+        return
+    elif source_type == SourceType.protobuf:
+        asset_plugin = ProtobufAssetPlugin()
+        kwargs = {
+            "files": files,
+            "include_unchanged_assets": include_unchanged_assets,
+        }
+        plugin_check(
+            asset_plugin,
+            output,  # type: ignore
+            include_unchanged_assets,
+            kwargs,
+            ctx,
+        )
+        return
     elif source_type == SourceType.typescript:
-        if not library and (
-            not emitter_function
-            or not emitter_payload_parameter
-            or not emitter_file_path
-            or (not event_name_key and not emitter_name_parameter)
-        ):
-            raise click.ClickException(
-                f"{EMOJI.RED_X.value} Missing required options for Typescript project registration. You can use the --help option for more details."
-            )
-        if not project_root:
-            raise click.ClickException(
-                f"{EMOJI.RED_X.value} Missing required option '--project-root' for Typescript project registration. You can use the --debug or --trace flags for more details."
-            )
-        results = check_compliance_typescript_data_asset(
-            ctx,
-            library,
-            node_modules_include,
-            project_root,
-            emitter_file_path,
-            emitter_function,
-            emitter_payload_parameter,
-            emitter_name_parameter,
-            event_name_key,
-            response_type,
+        asset_plugin = TypescriptAssetPlugin()
+        kwargs = {
+            "project_root": project_root,
+            "library": library,
+            "emitter_function": emitter_function,
+            "emitter_payload_parameter": emitter_payload_parameter,
+            "emitter_name_parameter": emitter_name_parameter,
+            "event_name_key": event_name_key,
+            "node_modules_include": node_modules_include,
+            "emitter_file_path": emitter_file_path,
+            "emitter_location": emitter_location or emitter_file_path,
+        }
+        plugin_check(
+            asset_plugin,
+            output,  # type: ignore
             include_unchanged_assets,
+            kwargs,
+            ctx,
         )
+        return
     elif source_type == SourceType.pyspark:
-        if not project_root or not (
-            connection_string or metastore_connection_string or csv_schema_file
-        ):
-            raise click.ClickException(
-                f"{EMOJI.RED_X.value} Missing required options for Spark project registration. You can use the --debug or --trace flags for more details."
-            )
-        if not spark_job_entrypoint:
-            if not config_file or not config_entrypoint_path:
-                raise click.ClickException(
-                    f"{EMOJI.RED_X.value} Missing required options for Spark project registration: --config-entrypoint-path is required when using --config-file."
-                )
-            spark_job_entrypoint = read_config_file(
-                config_file, config_entrypoint_path, config_args_path
-            )
-        results = check_compliance_pyspark_data_asset(
-            ctx,
-            spark_job_entrypoint,
-            project_root,
-            connection_string,
-            metastore_connection_string,
-            csv_schema_file,
-            csv_path_to_table_file,
-            response_type,  # type: ignore
+        kwargs = {
+            "spark_job_entrypoint": spark_job_entrypoint,
+            "project_root": project_root,
+            "connection_string": connection_string,
+            "metastore_connection_string": metastore_connection_string,
+            "csv_schema_file": csv_schema_file,
+            "csv_path_to_table_file": csv_path_to_table_file,
+            "include_unchanged_assets": include_unchanged_assets,
+            "response_type": response_type,
+        }
+        plugin_check(
+            PysparkAssetPlugin(),
+            output,  # type: ignore
             include_unchanged_assets,
+            kwargs,
+            ctx,
         )
+        return
     elif source_type == SourceType.s3:
         from gable.cli.helpers.data_asset_s3 import check_compliance_s3_data_assets
         from gable.cli.helpers.data_asset_s3 import validate_input as validate_s3_input
