@@ -28,6 +28,7 @@ from gable.openapi import (
     CheckDataAssetDetailedResponse,
     CheckDataAssetErrorResponse,
     CheckDataAssetMissingAssetResponse,
+    CheckDataAssetNoChangeResponse,
     CheckDataAssetNoContractResponse,
     CheckDataAssetResponse,
     EnforcementLevel,
@@ -263,6 +264,10 @@ def format_check_data_assets_text_output(
             results_strings.append(
                 f"{EMOJI.YELLOW_WARNING.value} {result.dataAssetPath}: No contract found"
             )
+        elif isinstance(result, CheckDataAssetNoChangeResponse):
+            results_strings.append(
+                f"{EMOJI.GREEN_CHECK.value} {result.dataAssetPath}: No changes in asset, skipping check"
+            )
     return (
         "\n".join(results_strings)
         + "\n\n"
@@ -374,6 +379,7 @@ def gather_typescript_asset_data(
         emitter_payload_parameter,
         event_name_key,
         emitter_name_parameter,
+        None,  # No exclude paths for now
         client,
     )
     return get_git_repo(project_root), {
@@ -422,3 +428,39 @@ def get_relative_project_path(project_root: str) -> Tuple[str, str]:
 
 def darn_to_string(darn: StructuredDataAssetResourceName) -> str:
     return f"{darn.source_type.value}://{darn.data_source}:{darn.path}"
+
+
+RECAP_TYPE_REGISTRY = None
+
+
+def recap_type_to_dict(recap_type) -> dict[str, Any]:
+    """
+    Converts a RecapType to a dictionary
+
+    Despite being called 'to_dict', this function can return a dictionary, a list or a
+    string. This is a wrapper function to convert the output of to_dict() to a
+    dictionary.
+
+    This should take a RecapType, but we can't annotate the function because we want to only import that inside the function
+    """
+    from recap.types import RecapType, RecapTypeRegistry, alias_dict, to_dict
+
+    recap_type_asserted: RecapType = recap_type
+
+    global RECAP_TYPE_REGISTRY
+    # Initialize this inside the function so we don't have to import the constructor at the top of the file
+    RECAP_TYPE_REGISTRY = RECAP_TYPE_REGISTRY or RecapTypeRegistry()
+
+    # Run alias_dict() separately so we can use a shared RecapTypeRegistry, otherwise
+    # a new instance of the class is created for each call which kills performance
+    recap_type_to_dict_output = to_dict(recap_type_asserted, True, False)
+    if isinstance(recap_type_to_dict_output, list):
+        type_dict = {"type": "union", "types": recap_type_to_dict_output}
+    elif isinstance(recap_type_to_dict_output, str):
+        type_dict = {"type": recap_type_to_dict_output}
+    else:
+        if recap_type_to_dict_output.get("type", None) is None:
+            recap_type_to_dict_output["type"] = "unknown"
+        type_dict = recap_type_to_dict_output
+    type_dict = alias_dict(type_dict, RECAP_TYPE_REGISTRY)
+    return type_dict
