@@ -8,13 +8,15 @@ import boto3
 import click
 from click.core import Context as ClickContext
 from gable.api.client import GableAPIClient
+from gable.cli.helpers.data_asset_s3.inventory_discovery import run_inventory_discovery
 from gable.cli.helpers.data_asset_s3.pattern_discovery import (
     discover_patterns_from_s3_bucket,
 )
 from gable.cli.helpers.data_asset_s3.schema_detection import (
     S3DetectionResult,
-    get_schema_from_s3_files,
+    read_s3_files_with_schema_inference,
     strip_s3_bucket_prefix,
+    append_s3_url_prefix
 )
 from gable.cli.helpers.emoji import EMOJI
 from gable.openapi import (
@@ -54,8 +56,10 @@ def register_and_check_s3_data_assets(
     include_prefix: Optional[tuple[str, ...]],
     exclude_prefix: Optional[tuple[str, ...]],
     include_unchanged_assets: bool,
-    dry_run: bool = False,
-    skip_profiling: bool = False,
+    dry_run: bool,
+    skip_profiling: bool,
+    use_inventory: bool,
+    inventory_dir: str,
 ) -> tuple[RegisterS3Response, CheckComplianceS3Response]:
     with warnings.catch_warnings():
         # Ignore FutureWarnings from pandas
@@ -72,6 +76,8 @@ def register_and_check_s3_data_assets(
             exclude_prefix,
             include_unchanged_assets,
             dry_run,
+            use_inventory,
+            inventory_dir,
         )
     if not results:
         raise click.ClickException(
@@ -171,6 +177,8 @@ def _process_s3_data_assets(
     exclude_prefix: Optional[tuple[str, ...]],
     include_unchanged_assets: bool,
     dry_run: bool = False,
+    use_inventory: bool = False,
+    inventory_dir: str = "",
 ) -> list[tuple[RegisterS3Response, CheckComplianceS3Response]]:
     """
     Detect data assets in S3 bucket. Register and check compliance of assets.
@@ -185,15 +193,25 @@ def _process_s3_data_assets(
     Returns:
         list[tuple[RegisterS3Response, CheckComplianceS3Response]]: Register and check API responses.
     """
-    patterns_to_urls = discover_patterns_from_s3_bucket(
-        get_s3_client(),
-        strip_s3_bucket_prefix(bucket_name),
-        recent_file_count,
-        start_date=datetime.now() - timedelta(days=lookback_days),
-        include_prefix=include_prefix,
-        exclude_prefix=exclude_prefix,
-        ignore_timeframe_bounds=False,
-    )
+    if use_inventory:
+        patterns_to_urls = run_inventory_discovery(
+            bucket=strip_s3_bucket_prefix(bucket_name),
+            inventory_dir=inventory_dir,
+            recent_file_count=recent_file_count,
+            include_prefix_list=list(include_prefix) if include_prefix else None,
+            exclude_prefix_list=list(exclude_prefix) if exclude_prefix else None,
+        )
+    else:
+        patterns_to_urls = discover_patterns_from_s3_bucket(
+            get_s3_client(),
+            strip_s3_bucket_prefix(bucket_name),
+            recent_file_count,
+            start_date=datetime.now() - timedelta(days=lookback_days),
+            include_prefix=include_prefix,
+            exclude_prefix=exclude_prefix,
+            ignore_timeframe_bounds=False,
+        )
+
     with ThreadPoolExecutor() as executor:
         results = executor.map(
             lambda entry: _register_and_check_s3_files(
@@ -207,7 +225,7 @@ def _process_s3_data_assets(
                 dry_run,
                 include_unchanged_assets,
             ),
-            patterns_to_urls.items(),
+            patterns_to_urls.items(),  # type: ignore
         )
         return list(results)
 
@@ -285,9 +303,21 @@ def _register_and_check_s3_files(
         skip_profiling (bool): Whether to compute data profiles.
         dry_run (bool): Whether to register detected data assets.
     """
-    if result := get_schema_from_s3_files(
-        bucket, event_name, s3_urls, row_sample_count, recent_file_count, skip_profiling
-    ):
+    full_urls = [
+        append_s3_url_prefix(
+            strip_s3_bucket_prefix(bucket),
+            key.lstrip("/")                     # ← remove any leading “/”
+        )
+        for key in s3_urls
+    ]
+    result: S3DetectionResult | None = read_s3_files_with_schema_inference(
+        s3_urls=full_urls,
+        row_sample_count=row_sample_count,
+        event_name=event_name,
+        recent_file_count=recent_file_count,
+        skip_profiling=skip_profiling,
+    )
+    if result :
         logger.info(
             f"Pattern: {event_name}\nSchema: {json.dumps(result.schema, indent=4)}"
         )
@@ -307,7 +337,7 @@ def _register_and_check_s3_files(
                         schema=result.schema,
                         fieldNameToDataAssetFieldProfileMap=result.data_asset_fields_to_profiles_map,
                         bucket=bucket,
-                        pattern=event_name,
+                        pattern=event_name.lstrip("/"),
                     )
                 ],
             )
@@ -358,9 +388,21 @@ def _get_and_check_compliance_merged_def_from_s3_files(
     Returns:
         tuple[dict, Optional[DataProfileFieldsMapping]]: Merged definition and data profile if able to be computed.
     """
-    if result := get_schema_from_s3_files(
-        bucket, event_name, s3_urls, row_sample_count, recent_file_count, skip_profiling
-    ):
+    full_urls = [
+        append_s3_url_prefix(
+            strip_s3_bucket_prefix(bucket),
+            key.lstrip("/")
+        )
+        for key in s3_urls
+    ]
+    result: S3DetectionResult | None = read_s3_files_with_schema_inference(
+       s3_urls=full_urls,
+       row_sample_count=row_sample_count,
+       event_name=event_name,
+       recent_file_count=recent_file_count,
+       skip_profiling=skip_profiling,
+   )
+    if result:
         return get_check_compliance_s3_results(
             result, bucket, event_name, response_type, client, include_unchanged_assets
         )
