@@ -225,25 +225,7 @@ class PathPatternManager:
         date = None
         for placeholder, regex in DATE_PLACEHOLDER_TO_REGEX.items():
             if match := re.search(regex, path):
-                if (
-                    any(
-                        [
-                            CompressionHandler.get_original_format(path).endswith(
-                                file_type.value
-                            )
-                            for file_type in SUPPORTED_FILE_TYPES
-                        ]
-                    )
-                    and "/" in regex
-                ):
-                    # if there's a / in the regex, we want to make sure we only replace the date part
-                    # for example, if the path is root/2024/01/01/data_03.csv, we only want to replace the date part
-                    # with date substitutions and replace the 03 with {N}. Without this logic, 03 will be inferred as
-                    # {HH} because data_ will match EQUALS_PREFIX_REGEX
-                    path_only, file = self.split_path_and_file(path)
-                    path = re.sub(regex, placeholder, path_only) + "/" + file
-                else:
-                    path = re.sub(regex, placeholder, path)
+                path = re.sub(regex, placeholder, path)
                 groups_without_delimiters = [
                     group
                     for index, group in enumerate(match.groups())
