@@ -5,6 +5,7 @@ import platform
 import shutil
 import subprocess
 import tempfile
+import threading
 from typing import Any, List, Optional, Union
 
 import click
@@ -14,6 +15,8 @@ from gable.cli.helpers.auth import set_npm_config_credentials
 from gable.openapi import CreateTelemetryRequest, TelemetryType
 from loguru import logger
 
+from gable.cli.local import get_local_sca_path, get_local_sca_prime
+
 BASE_NPX_CMD = [
     "npx",
     "-y",
@@ -153,7 +156,7 @@ def run_sca_python(
     except Exception as e:
         logger.opt(exception=e).debug("Error running Gable SCA")
         raise click.ClickException(
-            "Error running Gable SCA: Please ensure you have the @gable-eng/sca package installed."
+            "Error running Gable SCA, run again with --debug to see more details"
         )
 
 
@@ -166,13 +169,16 @@ def run_sca_typescript(
     emitter_payload_parameter: Optional[str],
     event_name_key: Optional[str],
     event_name_parameter: Optional[str],
+    exclude: Optional[str],
     client: GableAPIClient,
 ) -> tuple[str, dict[str, dict[str, Any]]]:
     try:
-        if library:
+        if library is not None:
             options = ["--library", library]
         else:
             options = [
+                # TODO: switch this to --emitter-location once the new NPM package is released
+                # and some time has passed
                 "--emitter-file-path",
                 emitter_file_path,
                 "--emitter-function",
@@ -180,21 +186,21 @@ def run_sca_typescript(
                 "--emitter-payload-parameter",
                 emitter_payload_parameter,
             ]
-            if event_name_key:
+            if event_name_key is not None:
                 options += ["--event-name-key", event_name_key]
-            else:
+            elif event_name_parameter is not None:
                 options += ["--event-name-parameter", event_name_parameter]
 
-        if node_modules_include:
+        if node_modules_include is not None:
             options += ["--node-modules-include", node_modules_include]
+        if exclude is not None:
+            options += ["--exclude", exclude]
 
         cmd = get_sca_cmd(
             client.endpoint,
             ["typescript", project_root] + options,
         )
-        sca_prime_shadow_results_future = start_sca_prime_shadow(
-            client, project_root, []
-        )
+        sca_prime_results_future = start_sca_prime(client, project_root, [])
         result = subprocess.run(
             cmd,
             stdout=subprocess.PIPE,
@@ -207,16 +213,16 @@ def run_sca_typescript(
         logger.debug(result.stdout)
         logger.debug(result.stderr)
 
-        # Run sca-prime in shadow-mode
-        shadow_results, _ = get_sca_prime_shadow_results(
-            sca_prime_shadow_results_future, client, project_root, True
+        # Run sca-prime
+        sca_prime_results, _ = get_sca_prime_results(
+            sca_prime_results_future, client, project_root, True
         )
         # The sca CLI prints the results to stdout,and everything else to trace/warn/debug/error
-        return (result.stdout, shadow_results)
+        return (result.stdout, sca_prime_results)
     except Exception as e:
         logger.opt(exception=e).debug("Error running Gable SCA")
         raise click.ClickException(
-            "Error running Gable SCA: Please ensure you have the @gable-eng/sca package installed."
+            "Error running Gable SCA, run again with --debug to see more details"
         )
 
 
@@ -240,7 +246,7 @@ def get_base_npx_cmd(gable_api_endpoint: Union[str, None]) -> list[str]:
     Returns: list[str] - The base command to run sca, either using npx + @gable-eng/sca or node + local path
     """
 
-    if os.environ.get("GABLE_CLI_ISOLATION", "false") == "true":
+    if should_use_docker_node_cmd():
         logger.debug(
             "GABLE_CLI_ISOLATION is true, passing DOCKER_NODE_CMD", DOCKER_NODE_CMD
         )
@@ -249,9 +255,6 @@ def get_base_npx_cmd(gable_api_endpoint: Union[str, None]) -> list[str]:
     if should_use_local_sca(gable_api_endpoint):
         logger.trace("Configuring local settings")
         try:
-            # Needs to be a dynamic import because this file is excluded from the bundled package
-            from gable.cli.local import get_local_sca_path
-
             local_sca_path = get_local_sca_path()
             return [
                 "node",
@@ -271,6 +274,10 @@ def get_base_npx_cmd(gable_api_endpoint: Union[str, None]) -> list[str]:
     return BASE_NPX_CMD
 
 
+def should_use_docker_node_cmd() -> bool:
+    return os.environ.get("GABLE_CLI_ISOLATION", "false") == "true"
+
+
 def should_use_local_sca(gable_api_endpoint: Optional[str]) -> bool:
     """Based on the GABLE_LOCAL environment variable and API endpoint, decide if we should use the local package"""
     gable_local = os.environ.get("GABLE_LOCAL")
@@ -295,7 +302,7 @@ def get_installed_package_dir() -> str:
     raise Exception("SCA package not found in npx cache")
 
 
-def start_sca_prime_shadow(
+def start_sca_prime(
     client: GableAPIClient,
     project_root: str,
     annotations: List[str],
@@ -303,13 +310,13 @@ def start_sca_prime_shadow(
     semgrep_bin_path: Optional[str] = None,
 ) -> Union[tuple[subprocess.Popen, str], None]:
     # return process and tempdir if no error, else None
-    if os.environ.get("ENABLE_SCA_PRIME_SHADOW", "true").lower() != "true":
+    if os.environ.get("ENABLE_SCA_PRIME", "true").lower() != "true":
         return None
 
     os.environ["SEMGREP_DEPLOY_CORE_BIN_PATH"] = semgrep_bin_path or ""
 
     try:
-        logger.debug("Running SCA Prime in shadow mode")
+        logger.debug("Running SCA Prime")
         sca_prime_path = _get_sca_prime_path(client.endpoint)
 
         if not sca_prime_path:
@@ -333,16 +340,34 @@ def start_sca_prime_shadow(
         if sca_debug:
             command += ["--debug"]
 
+        logger.debug("Running sca-prime command: {}", " ".join(command))
         process = subprocess.Popen(
             command,
+            env=os.environ,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
-            env=os.environ,
             text=True,
         )
+
+        def stream_output(pipe, log_method, label):
+            with pipe:
+                for line in pipe:
+                    log_method(f"[{label}] {line.rstrip()}")
+
+        # Start threads for stdout and stderr
+        stdout_thread = threading.Thread(
+            target=stream_output, args=(process.stdout, logger.trace, "STDOUT")
+        )
+        stderr_thread = threading.Thread(
+            target=stream_output, args=(process.stderr, logger.trace, "STDERR")
+        )
+
+        stdout_thread.start()
+        stderr_thread.start()
+
         return (process, temp_dir)
     except Exception as e:
-        logger.opt(exception=e).debug(f"Error running SCA Prime in shadow mode {e}", e)
+        logger.opt(exception=e).debug(f"Error running SCA Prime: {e}", e)
         return None
 
 
@@ -367,11 +392,11 @@ def run_sca_npx_help(
     except Exception as e:
         logger.opt(exception=e).debug("Error running Gable SCA")
         raise click.ClickException(
-            "Error running Gable SCA: Please ensure you have the @gable-eng/sca package installed."
+            "Error running Gable SCA, run again with --debug to see more details"
         )
 
 
-def get_sca_prime_shadow_results(
+def get_sca_prime_results(
     sca_prime_process_data: Union[tuple[subprocess.Popen, str], None],
     client: GableAPIClient,
     project_root: str,
@@ -381,13 +406,7 @@ def get_sca_prime_shadow_results(
         return {}, {}
     sca_prime_process, temp_dir = sca_prime_process_data
     try:
-        stdout, stderr = sca_prime_process.communicate()
-        logger.trace("--------------------SCA PRIME STDOUT-------------------")
-        logger.trace(stdout)
-        logger.trace("--------------------SCA PRIME STDERR-------------------")
-        logger.trace(stderr)
-        logger.trace("-------------------------------------------------------")
-
+        sca_prime_process.wait()
         if post_metrics:
             metrics_file = os.path.join(temp_dir, "metrics.json")
             if os.path.exists(metrics_file):
@@ -450,10 +469,7 @@ def _get_sca_prime_path(gable_api_endpoint: Union[str, None]) -> Union[str, None
     """Returns the path to SCA prime"""
     architecture = _get_host_architecture_for_sca_prime_binary()
     if should_use_local_sca(gable_api_endpoint):
-        # Needs to be a dynamic import because this file is excluded from the bundled package
-        from gable.cli.local import get_local_sca_prime
-
-        local_sca_prime = get_local_sca_prime(architecture)
+        local_sca_prime = get_local_sca_prime()
         logger.debug(f"Using local SCA prime: {local_sca_prime}")
         return local_sca_prime
     return os.path.join(
