@@ -2,8 +2,7 @@ import functools
 import re
 import sys
 import traceback
-from enum import Enum
-from typing import Literal, Optional
+from typing import List, Literal, Optional
 
 import click
 from click_option_group import OptionGroup, optgroup
@@ -18,14 +17,13 @@ from gable.common_types import DATABASE_SOURCE_TYPES, FILE_SOURCE_TYPES
 from gable.openapi import SourceType
 from loguru import logger
 
-
-class TypescriptLibrary(Enum):
-    BRANDVIEWS = "brandviews"
-    SEGMENT = "segment"
-    AMPLITUDE = "amplitude"
-
-
-ALL_TYPESCRIPT_LIBRARY_VALUES = [library.value for library in TypescriptLibrary]
+TypescriptLibrary = Literal["brandviews", "segment", "amplitude", "udf"]
+ALL_TYPESCRIPT_LIBRARY_VALUES: List[TypescriptLibrary] = [
+    "brandviews",
+    "segment",
+    "amplitude",
+    "udf",
+]
 
 
 class Context:
@@ -240,13 +238,18 @@ def source_type_dependent_required_option_callback(ctx, param, value):
     return value
 
 
+PYTHON_EVENT_NAME_KEY_REGEX = (
+    r"^(\w+|\*|\[\*\]|\[-?[0-9]+\])(\.(\w+|\[\*\]|\[-?[0-9]+\]))*\w+$"
+)
+
+
 def python_event_name_key_validator(param: click.Parameter, value: str) -> None:
     # Event name key must be a valid access path:
     # 1. The string can start with a word (letters, digits, underscores), *, [*], or [<index>].
     # 2. If there is a dot separator, it should be followed by a word, [*], or [<index>]. This process can repeat (zero or more times).
     # 3. The string must end with a word.
     if param.opts[0] == "--event-name-key" and not re.match(
-        r"^(\w+|\*|\[\*\]|\[-?[0-9]+\])(\.(\w+|\[\*\]|\[-?[0-9]+\]))*\w+$", value
+        PYTHON_EVENT_NAME_KEY_REGEX, value
     ):
         raise click.BadParameter(value + " must be valid event name access path")
 
@@ -453,13 +456,18 @@ def typescript_project_options(
             type=str,
         )
         @optgroup.option(
-            "--emitter-file-path",
-            help="Relative path from the root of the project to the file that contains the emitter function",
+                "--emitter-file-path",
+                help="DEPRECATED: Use --emitter-location instead.",
+                type=str,
+            )
+        @optgroup.option(
+            "--emitter-location",
+            help="NPM package name, or relative path from the root of the project to the file that contains the emitter function",
             type=str,
         )
         @optgroup.option(
             "--emitter-function",
-            help="Name of the emitter function",
+            help="Name of the emitter function. This can be a standalone function like 'trackEvent' or a class method like 'AnalyticsClient.track'",
             type=str,
         )
         @optgroup.option(
@@ -477,6 +485,15 @@ def typescript_project_options(
             help="Name of the event property that contains the event name. Either this option, or the --emitter-name-parameter option must be provided when using --emitter-function.",
             type=str,
         )
+        @optgroup.option(
+                "--exclude",
+                help="Comma delimited list of filenames or extended globbing patterns of node modules to include in the analysis. Defaults toexclude common test patterns like *.test.js, *.spec.js, etc.",
+                type=str,
+                # TODO: Removed the default value until the new SCA tool will be released that supports this option.
+                #default="**/*.@(test|spec).@(js|jsx|ts|tsx|mjs|mts|cjs|cts),**/@(test|tests|spec)/**",
+                #show_default=True,
+                default=None,
+            )
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             return func(*args, **kwargs)
@@ -506,7 +523,7 @@ def proxy_database_options(
             type=str,
             callback=source_type_dependent_required_option_callback,
             help="""The host name of the production database, for example 'service-one.xxxxxxxxxxxx.us-east-1.rds.amazonaws.com'.
-            Despite not needing to connect to the production database, the host is still needed to generate the unique resource 
+            Despite not needing to connect to the production database, the host is still needed to generate the unique resource
             name for the real database tables (data assets).
             """,
         )
@@ -515,7 +532,7 @@ def proxy_database_options(
             "-p",
             type=int,
             callback=source_type_dependent_required_option_callback,
-            help="""The port of the production database. Despite not needing to connect to the production database, the port is 
+            help="""The port of the production database. Despite not needing to connect to the production database, the port is
             still needed to generate the unique resource name for the real database tables (data assets).
             """,
         )
@@ -523,15 +540,15 @@ def proxy_database_options(
             "--db",
             type=str,
             callback=source_type_dependent_required_option_callback,
-            help="""The name of the production database. Despite not needing to connect to the production database, the database 
+            help="""The name of the production database. Despite not needing to connect to the production database, the database
             name is still needed to generate the unique resource name for the real database tables (data assets).
-            
-            Database naming convention frequently includes the environment (production/development/test/staging) in the 
-            database name, so this value may not match the name of the database in the proxy database instance. If this is 
-            the case, you can set the --proxy-db value to the name of the database in the proxy instance, but we'll use the 
+
+            Database naming convention frequently includes the environment (production/development/test/staging) in the
+            database name, so this value may not match the name of the database in the proxy database instance. If this is
+            the case, you can set the --proxy-db value to the name of the database in the proxy instance, but we'll use the
             value of --db to generate the unique resource name for the data asset.
-            
-            For example, if your production database is 'prod_service_one', but your test database is 'test_service_one', 
+
+            For example, if your production database is 'prod_service_one', but your test database is 'test_service_one',
             you would set --db to 'prod_service_one' and --proxy-db to 'test_service_one'.""",
         )
         @optgroup.option(
@@ -539,16 +556,16 @@ def proxy_database_options(
             "-s",
             type=str,
             callback=source_type_dependent_required_option_callback,
-            help=f"""The schema of the production database containing the table(s) to {action}. Despite not needing to connect to 
+            help=f"""The schema of the production database containing the table(s) to {action}. Despite not needing to connect to
             the production database, the schema is still needed to generate the unique resource name for the real database tables
             (data assets).
-            
-            Database naming convention frequently includes the environment (production/development/test/staging) in the 
-            schema name, so this value may not match the name of the schema in the proxy database instance. If this is 
-            the case, you can set the --proxy-schema value to the name of the schema in the proxy instance, but we'll use the 
+
+            Database naming convention frequently includes the environment (production/development/test/staging) in the
+            schema name, so this value may not match the name of the schema in the proxy database instance. If this is
+            the case, you can set the --proxy-schema value to the name of the schema in the proxy instance, but we'll use the
             value of --schema to generate the unique resource name for the data asset.
-            
-            For example, if your production schema is 'production', but your test database is 'test', 
+
+            For example, if your production schema is 'production', but your test database is 'test',
             you would set --schema to 'production' and --proxy-schema to 'test'.""",
         )
         @optgroup.option(
@@ -568,8 +585,8 @@ def proxy_database_options(
             "-ph",
             type=str,
             callback=source_type_dependent_required_option_callback,
-            help=f"""The host string of the database instance that serves as the proxy for the production database. This is the 
-            database that Gable will connect to when {action}ing tables in the CI/CD workflow. 
+            help=f"""The host string of the database instance that serves as the proxy for the production database. This is the
+            database that Gable will connect to when {action}ing tables in the CI/CD workflow.
             """,
         )
         @optgroup.option(
@@ -577,8 +594,8 @@ def proxy_database_options(
             "-pp",
             type=int,
             callback=source_type_dependent_required_option_callback,
-            help=f"""The port of the database instance that serves as the proxy for the production database. This is the 
-            database that Gable will connect to when {action}ing tables in the CI/CD workflow. 
+            help=f"""The port of the database instance that serves as the proxy for the production database. This is the
+            database that Gable will connect to when {action}ing tables in the CI/CD workflow.
             """,
         )
         @optgroup.option(
@@ -588,10 +605,10 @@ def proxy_database_options(
             callback=check_for_empty_string_callback,
             default=None,
             help="""Only needed if the name of the database in the proxy instance is different than the name of the
-            production database. If not specified, the value of --db will be used to generate the unique resource name for 
-            the data asset. 
-            
-            For example, if your production database is 'prod_service_one', but your test database is 'test_service_one', 
+            production database. If not specified, the value of --db will be used to generate the unique resource name for
+            the data asset.
+
+            For example, if your production database is 'prod_service_one', but your test database is 'test_service_one',
             you would set --db to 'prod_service_one' and --proxy-db to 'test_service_one'.
             """,
         )
@@ -602,9 +619,9 @@ def proxy_database_options(
             callback=check_for_empty_string_callback,
             default=None,
             help="""Only needed if the name of the schema in the proxy instance is different than the name of the schema in the
-            production database. If not specified, the value of --schema will be used to generate the unique resource name for 
-            the data asset. 
-            
+            production database. If not specified, the value of --schema will be used to generate the unique resource name for
+            the data asset.
+
             For example, if your production schema is 'production', but your test database is 'test', you would set --schema to
             'production' and --proxy-schema to 'test'.
             """,
@@ -614,8 +631,8 @@ def proxy_database_options(
             "-pu",
             type=str,
             callback=source_type_dependent_required_option_callback,
-            help=f"""The user that will be used to connect to the proxy database instance that serves as the proxy for the production 
-            database. This is the database that Gable will connect to when {action}ing tables in the CI/CD workflow. 
+            help=f"""The user that will be used to connect to the proxy database instance that serves as the proxy for the production
+            database. This is the database that Gable will connect to when {action}ing tables in the CI/CD workflow.
             """,
         )
         @optgroup.option(
@@ -623,8 +640,8 @@ def proxy_database_options(
             "-ppw",
             type=str,
             default=None,
-            help=f"""If specified, the password that will be used to connect to the proxy database instance that serves as the proxy for 
-            the production database. This is the database that Gable will connect to when {action}ing tables in the CI/CD workflow. 
+            help=f"""If specified, the password that will be used to connect to the proxy database instance that serves as the proxy for
+            the production database. This is the database that Gable will connect to when {action}ing tables in the CI/CD workflow.
             """,
         )
         @functools.wraps(func)
@@ -672,7 +689,7 @@ def s3_project_options(
             "--lookback-days",
             type=int,
             default=2,
-            help="""Number of days to look back from the latest day in the list of paths, defaults to 2. 
+            help="""Number of days to look back from the latest day in the list of paths, defaults to 2.
             For example if the latest path is 2024/01/02, and lookback_days is 3, then the paths return
             will have 2024/01/02, 2024/01/01, and 2023/12/31
             """,
@@ -713,6 +730,20 @@ def s3_project_options(
         def wrapper(*args, **kwargs):
             return func(*args, **kwargs)
 
-        return wrapper
+        if action == "register":
+            wrapped = optgroup.option(
+                "--use-inventory",
+                is_flag=True,
+                default=False,
+                help="Enable S3 Inventory-based discovery instead of listing files live from S3.",
+            )(wrapper)
+
+            wrapped = optgroup.option(
+                "--inventory-dir",
+                type=str,
+                help="Local directory or S3 URI where inventory .csv.gz files are stored. Used when --use-inventory is enabled.",
+            )(wrapped)
+
+        return functools.wraps(func)(wrapper)
 
     return decorator
